referrerpolicy=no-referrer-when-downgrade

remove_potential_renewal

Function remove_potential_renewal 

pub fn remove_potential_renewal<T: Config>(core: CoreIndex, when: Timeslice)
Forcefully remove a potential renewal record from chain.

Note that only the specified potential renewal will be removed while any related auto renewals will stay intact and will fail.

  • origin: Must be Root or pass AdminOrigin.
  • core: Core which the target potential renewal record refers to.
  • when: Timeslice which the target potential renewal record refers to.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::remove_potential_renewal.