pub fn force_transfer<T: Config>(region_id: RegionId, new_owner: T::AccountId)Expand description
Transfer a Bulk Coretime Region to a new owner, ignoring the previous owner.
This can also be used to recover regions that have been “burned” (e.g., from an XCM reserve transfer).
origin: Must be Root or passAdminOrigin.region_id: The Region whose ownership should change.new_owner: The new owner for the Region.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::force_transfer.