pub fn remove_potential_renewal<T: Config>(core: CoreIndex, when: Timeslice)Expand description
Forcefully remove a potential renewal record from chain.
Note that only the specified potential renewal will be removed while any related auto renewals will stay intact and will fail.
origin: Must be Root or passAdminOrigin.core: Core which the target potential renewal record refers to.when: Timeslice which the target potential renewal record refers to.
Warning: Doc-Only
This function is an automatically generated, and is doc-only, uncallable
stub. See the real version in
Pallet::remove_potential_renewal.